# jwrite

![GPL-3.0 License](https://img.shields.io/github/license/jrrom/jwrite)
![100% Python, except the parts not shown here](https://img.shields.io/github/languages/top/jrrom/jwrite)
![Version](https://img.shields.io/pypi/v/jwrite)
![Supports Python 3.7, 3.8, 3.9, 3.10 and 3.11](https://img.shields.io/pypi/pyversions/jwrite)

## About -

This is a minimal notepad clone made to learn [PySide6](https://doc.qt.io/qtforpython/index.html) for a school project. It uses QUI files for structuring its main components.
Download the package using `pip install jwrite` or `pip3 install jwrite`

## Showcase -
Video - https://youtu.be/YS1AV7d7t88

![New Screen](https://user-images.githubusercontent.com/77691121/209984324-055cfa72-f1dd-4d82-9594-d86b559e3ce5.png)
![Some text selected](https://user-images.githubusercontent.com/77691121/209984428-f2fb929d-bd84-49cf-89cc-3cde30bea61d.png)
![About Page](https://user-images.githubusercontent.com/77691121/209984573-59ed67d0-6a6a-44b7-b23a-eb5107a9a70f.png)
